editionMap = {
			 "Greece": "el_gr",
			 "Indonesia": "id_id",
			 "Romania": "ro_ro",
			 "Philippines": "en_ph",
			 "Zimbabwe": "en_zw",
			 "Sweden": "sv_se",
			 "Saudi Arabia": "ar_sa",
			 "Australia": "au",
			 "Belgium (Dutch)": "nl_be",
			 "Hungary": "hu_hu",
			 "Chile": "es_cl",
			 "Belgium (French)": "fr_be",
			 "Mexico": "es_mx",
			 "Hong Kong": "hk",
			 "Turkey": "tr_tr",
			 "Ireland": "en_ie",
			 "Ghana": "en_gh",
			 "Argentina": "es_ar",
			 "Slovakia": "sk_sk",
			 "New Zealand": "nz",
			 "India (English)": "in",
			 "Vietnam": "vi_vn",
			 "Canada (French)": "fr_ca",
			 "Uganda": "en_ug",
			 "Italy": "it",
			 "Morocco": "fr_ma",
			 "Japan": "jp",
			 "India (Telugu)": "te_in",
			 "Russia": "ru_ru",
			 "Canada (English)": "ca",
			 "Bulgaria": "bg_bg",
			 "Switzerland": "fr_ch",
			 "Slovenia": "sl_si",
			 "India (Hindi)": "hi_in",
			 "Nigeria": "en_ng",
			 "Israel (Hebrew)": "iw_il",
			 "United Kingdom": "uk",
			 "Bangladesh": "bn_bd",
			 "Netherlands": "nl_nl",
			 "Pakistan": "en_pk",
			 "Cuba": "es_cu",
			 "United States (English)": "us",
			 "Namibia": "en_na",
			 "Ukraine (Russian)": "ru_ua",
			 "Serbia": "sr_rs",
			 "Arab world": "ar_me",
			 "Brazil": "pt-BR_br",
			 "Lebanon": "ar_lb",
			 "Czech Republic": "cs_cz",
			 "France": "fr",
			 "India (Malayalam)": "ml_in",
			 "China": "cn",
			 "Thailand": "th_th",
			 "Ethiopia": "en_et",
			 "Colombia": "es_co",
			 "Poland": "pl_pl",
			 "Botswana": "en_bw",
			 "Germany": "de",
			 "Egypt": "ar_eg",
			 "Peru": "es_pe",
			 "Senegal": "fr_sn",
			 "Ukraine (Ukranian)": "uk_ua",
			 "United States (Spanish)": "es_us",
			 "Singapore": "en_sg",
			 "Kenya": "en_ke",
			 "Taiwan": "tw",
			 "Israel (English)": "en_il",
			 "Venezuela": "es_ve",
			 "South Africa": "en_za",
			 "Austria": "de_at",
			 "Portugal": "pt-PT_pt",
			 "Lithuania": "lt_lt",
			 "India (Tamil)": "ta_in",
			 "Malaysia": "en_my",
			 "United Arab Emirates": "ar_ae",
			 "Tanzania": "en_tz",
			 "Latvia": "lv_lv",
			 "Norway": "no_no"
			}


topicMap = {
			 "sports": "s",
			 "politics": "p",
			 "top stories": "",
			 "national": "n",
			 "entertainment": "e",
			 "technology": "t",
			 "business": "b",
			 "world": "w"
			}


langMap = {
			 'afrikaans': 'af',
			 'albanian': 'sq',
			 'arabic': 'ar',
			 'azerbaijani': 'az',
			 'basque': 'eu',
			 'belarusian': 'be',
			 'bengali': 'bn',
			 'bulgarian': 'bg',
			 'catalan': 'ca',
			 'chinese simplified': 'zh-CN',
			 'chinese traditional': 'zh-TW',
			 'croatian': 'hr',
			 'czech': 'cs',
			 'danish': 'da',
			 'dutch': 'nl',
			 'english': 'en',
			 'esperanto': 'eo',
			 'estonian': 'et',
			 'filipino': 'tl',
			 'finnish': 'fi',
			 'french': 'fr',
			 'galician': 'gl',
			 'georgian': 'ka',
			 'german': 'de',
			 'greek': 'el',
			 'gujarati': 'gu',
			 'haitian creole': 'ht',
			 'hebrew': 'iw',
			 'hindi': 'hi',
			 'hungarian': 'hu',
			 'icelandic': 'is',
			 'indonesian': 'id',
			 'irish': 'ga',
			 'italian': 'it',
			 'japanese': 'ja',
			 'kannada': 'kn',
			 'korean': 'ko',
			 'latin': 'la',
			 'latvian': 'lv',
			 'lithuanian': 'lt',
			 'macedonian': 'mk',
			 'malay': 'ms',
			 'maltese': 'mt',
			 'norwegian': 'no',
			 'persian': 'fa',
			 'polish': 'pl',
			 'portuguese': 'pt',
			 'romanian': 'ro',
			 'russian': 'ru',
			 'serbian': 'sr',
			 'slovak': 'sk',
			 'slovenian': 'sl',
			 'spanish': 'es',
			 'swahili': 'sw',
			 'swedish': 'sv',
			 'tamil': 'ta',
			 'telugu': 'te',
			 'thai': 'th',
			 'turkish': 'tr',
			 'ukrainian': 'uk',
			 'urdu': 'ur',
			 'vietnamese': 'vi',
			 'welsh': 'cy',
			 'yiddish': 'yi'
			}
